abacusai.deployment_conversation_export — AbacusAI documentation

# `abacusai.deployment_conversation_export`

## Module Contents

### Classes

`DeploymentConversationExport` | A deployment conversation html export, to be used for downloading the conversation.

class abacusai.deployment_conversation_export.DeploymentConversationExport(client, deploymentConversationId=None, conversationExportHtml=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  A deployment conversation html export, to be used for downloading the conversation.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - deploymentConversationId (str) – The unique identifier of the deployment conversation.

    - conversationExportHtml (str) – The html string of the deployment conversation.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict